@@ -13,9 +13,10 @@
 #    limitations under the License.
 
 import copy
-import json
 import six
 
+from oslo_serialization import jsonutils
+
 from keystoneauth1 import exceptions
 
 urlparse = six.moves.urllib.parse
@@ -134,7 +135,7 @@ class ResourceManager(object):
 
     def _create(self, url, data, response_key=None, dump_json=True):
         if dump_json:
-            data = json.dumps(data)
+            data = jsonutils.dumps(data)
 
         try:
             resp = self.http_client.post(url, data)
@@ -148,7 +149,7 @@ class ResourceManager(object):
 
     def _update(self, url, data, response_key=None, dump_json=True):
         if dump_json:
-            data = json.dumps(data)
+            data = jsonutils.dumps(data)
 
         try:
             resp = self.http_client.put(url, data)
@@ -216,7 +217,7 @@ def get_json(response):
     if callable(json_field_or_function):
         return response.json()
     else:
-        return json.loads(response.content)
+        return jsonutils.loads(response.content)
 
 
 class APIException(Exception):
